@@ -38,8 +38,6 @@
 
 #define QT_FEATURE_pulseaudio 1
 
-#define QT_FEATURE_wmsdk -1
-
 #define QT_FEATURE_opensles -1
 
 #define QT_FEATURE_wasm -1
@@ -50,3 +48,5 @@
 
 #define QT_FEATURE_spatialaudio_quick3d 1
 
+#define QT_FEATURE_ffmpeg_stubs -1
+
